# Semantic Similarity Metrics

GAICo provides a semantic similarity metric to evaluate the semantic similarity between text inputs.

This metric is useful for tasks such as semantic text matching, paraphrase detection, and understanding the meaning of text in a more nuanced way.

::: gaico.metrics.semantic_similarity_metrics.BERTScore
